@@ -429,6 +429,7 @@ addDateOfBirthQuery <- function(x,
                                   futureObservationType,
                                   dateOfBirth,
                                   dateOfBirthName,
+                                  tmpName = NULL,
                                   call = parent.frame()) {
   # initial checks
   x <- omopgenerics::validateCdmTable(table = x)
@@ -514,9 +515,17 @@ addDateOfBirthQuery <- function(x,
       fOQ <- NULL
     }
 
-    observationPeriod <- x |>
+    distinctSubjects <- x |>
       dplyr::select(dplyr::all_of(c(personVariable, indexDate))) |>
-      dplyr::distinct() |>
+      dplyr::distinct()
+
+    if(!is.null(tmpName)){
+      distinctSubjects <- distinctSubjects  |> dplyr::compute(name = tmpName,
+                                                              temporary = FALSE,
+                                                              logPrefix = "PatientProfiles.addDemographicsQuery_distinctSubjects")
+    }
+
+    observationPeriod <- distinctSubjects |>
       dplyr::inner_join(
         cdm[["observation_period"]] |>
           dplyr::select(
@@ -535,6 +544,12 @@ addDateOfBirthQuery <- function(x,
         personVariable, indexDate, priorObservationName, futureObservationName
       )))
 
+    if(!is.null(tmpName)){
+      observationPeriod <- observationPeriod  |> dplyr::compute(name = tmpName,
+                                                                temporary = FALSE,
+                                                                logPrefix = "PatientProfiles.addDemographicsQuery_observationPeriod")
+    }
+
     xnew <- x |>
       dplyr::left_join(observationPeriod, by = c(personVariable, indexDate))
   } else {
